# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import DataService_pb2 as DataService__pb2


class DataServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.UploadData = channel.stream_unary(
        '/xgt.DataService/UploadData',
        request_serializer=DataService__pb2.UploadDataRequest.SerializeToString,
        response_deserializer=DataService__pb2.UploadDataResponse.FromString,
        )
    self.DownloadData = channel.unary_stream(
        '/xgt.DataService/DownloadData',
        request_serializer=DataService__pb2.DownloadDataRequest.SerializeToString,
        response_deserializer=DataService__pb2.DownloadDataResponse.FromString,
        )
    self.IngestUri = channel.unary_unary(
        '/xgt.DataService/IngestUri',
        request_serializer=DataService__pb2.IngestUriRequest.SerializeToString,
        response_deserializer=DataService__pb2.IngestUriResponse.FromString,
        )
    self.EgestUri = channel.unary_unary(
        '/xgt.DataService/EgestUri',
        request_serializer=DataService__pb2.EgestUriRequest.SerializeToString,
        response_deserializer=DataService__pb2.EgestUriResponse.FromString,
        )


class DataServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def UploadData(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DownloadData(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def IngestUri(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EgestUri(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DataServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'UploadData': grpc.stream_unary_rpc_method_handler(
          servicer.UploadData,
          request_deserializer=DataService__pb2.UploadDataRequest.FromString,
          response_serializer=DataService__pb2.UploadDataResponse.SerializeToString,
      ),
      'DownloadData': grpc.unary_stream_rpc_method_handler(
          servicer.DownloadData,
          request_deserializer=DataService__pb2.DownloadDataRequest.FromString,
          response_serializer=DataService__pb2.DownloadDataResponse.SerializeToString,
      ),
      'IngestUri': grpc.unary_unary_rpc_method_handler(
          servicer.IngestUri,
          request_deserializer=DataService__pb2.IngestUriRequest.FromString,
          response_serializer=DataService__pb2.IngestUriResponse.SerializeToString,
      ),
      'EgestUri': grpc.unary_unary_rpc_method_handler(
          servicer.EgestUri,
          request_deserializer=DataService__pb2.EgestUriRequest.FromString,
          response_serializer=DataService__pb2.EgestUriResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'xgt.DataService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: JobService.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='JobService.proto',
  package='xgt',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x10JobService.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb8\x01\n\tJobStatus\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0e\n\x06job_id\x18\x02 \x01(\x04\x12\"\n\x06status\x18\x03 \x01(\x0e\x32\x12.xgt.JobStatusEnum\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"i\n\x19ScheduleJobsCypherRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x14\n\x0c\x63ypher_query\x18\x02 \x03(\t\x12\x1a\n\x12optimization_level\x18\x03 \x01(\x05\"[\n\x1aScheduleJobsCypherResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus\"?\n\x11\x43\x61ncelJobsRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x0e\n\x06job_id\x18\x02 \x03(\x04\"S\n\x12\x43\x61ncelJobsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus\"<\n\x0eGetJobsRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x0e\n\x06job_id\x18\x02 \x03(\x04\"P\n\x0fGetJobsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus*\xbf\x01\n\rJobStatusEnum\x12\x16\n\x12UNKNOWN_JOB_STATUS\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x19\n\x15TRANSACTIONNOTSTARTED\x10\x06\x12\x19\n\x15TRANSACTIONCOMMITTING\x10\x07\x12\x1b\n\x17TRANSACTIONNOTCOMMITTED\x10\x08\x32\xde\x01\n\nJobService\x12W\n\x12ScheduleJobsCypher\x12\x1e.xgt.ScheduleJobsCypherRequest\x1a\x1f.xgt.ScheduleJobsCypherResponse\"\x00\x12?\n\nCancelJobs\x12\x16.xgt.CancelJobsRequest\x1a\x17.xgt.CancelJobsResponse\"\x00\x12\x36\n\x07GetJobs\x12\x13.xgt.GetJobsRequest\x1a\x14.xgt.GetJobsResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[ErrorMessages__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_JOBSTATUSENUM = _descriptor.EnumDescriptor(
  name='JobStatusEnum',
  full_name='xgt.JobStatusEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_JOB_STATUS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONNOTSTARTED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONCOMMITTING', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONNOTCOMMITTED', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=761,
  serialized_end=952,
)
_sym_db.RegisterEnumDescriptor(_JOBSTATUSENUM)

JobStatusEnum = enum_type_wrapper.EnumTypeWrapper(_JOBSTATUSENUM)
UNKNOWN_JOB_STATUS = 0
SCHEDULED = 1
RUNNING = 2
COMPLETED = 3
CANCELED = 4
FAILED = 5
TRANSACTIONNOTSTARTED = 6
TRANSACTIONCOMMITTING = 7
TRANSACTIONNOTCOMMITTED = 8



_JOBSTATUS = _descriptor.Descriptor(
  name='JobStatus',
  full_name='xgt.JobStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.JobStatus.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='xgt.JobStatus.job_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='xgt.JobStatus.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='xgt.JobStatus.start_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='xgt.JobStatus.end_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=264,
)


_SCHEDULEJOBSCYPHERREQUEST = _descriptor.Descriptor(
  name='ScheduleJobsCypherRequest',
  full_name='xgt.ScheduleJobsCypherRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.ScheduleJobsCypherRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cypher_query', full_name='xgt.ScheduleJobsCypherRequest.cypher_query', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimization_level', full_name='xgt.ScheduleJobsCypherRequest.optimization_level', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=371,
)


_SCHEDULEJOBSCYPHERRESPONSE = _descriptor.Descriptor(
  name='ScheduleJobsCypherResponse',
  full_name='xgt.ScheduleJobsCypherResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.ScheduleJobsCypherResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_status', full_name='xgt.ScheduleJobsCypherResponse.job_status', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=464,
)


_CANCELJOBSREQUEST = _descriptor.Descriptor(
  name='CancelJobsRequest',
  full_name='xgt.CancelJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.CancelJobsRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='xgt.CancelJobsRequest.job_id', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=529,
)


_CANCELJOBSRESPONSE = _descriptor.Descriptor(
  name='CancelJobsResponse',
  full_name='xgt.CancelJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.CancelJobsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_status', full_name='xgt.CancelJobsResponse.job_status', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=531,
  serialized_end=614,
)


_GETJOBSREQUEST = _descriptor.Descriptor(
  name='GetJobsRequest',
  full_name='xgt.GetJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.GetJobsRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='xgt.GetJobsRequest.job_id', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=676,
)


_GETJOBSRESPONSE = _descriptor.Descriptor(
  name='GetJobsResponse',
  full_name='xgt.GetJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.GetJobsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_status', full_name='xgt.GetJobsResponse.job_status', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=758,
)

_JOBSTATUS.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_JOBSTATUS.fields_by_name['status'].enum_type = _JOBSTATUSENUM
_JOBSTATUS.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBSTATUS.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULEJOBSCYPHERRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_SCHEDULEJOBSCYPHERRESPONSE.fields_by_name['job_status'].message_type = _JOBSTATUS
_CANCELJOBSRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_CANCELJOBSRESPONSE.fields_by_name['job_status'].message_type = _JOBSTATUS
_GETJOBSRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_GETJOBSRESPONSE.fields_by_name['job_status'].message_type = _JOBSTATUS
DESCRIPTOR.message_types_by_name['JobStatus'] = _JOBSTATUS
DESCRIPTOR.message_types_by_name['ScheduleJobsCypherRequest'] = _SCHEDULEJOBSCYPHERREQUEST
DESCRIPTOR.message_types_by_name['ScheduleJobsCypherResponse'] = _SCHEDULEJOBSCYPHERRESPONSE
DESCRIPTOR.message_types_by_name['CancelJobsRequest'] = _CANCELJOBSREQUEST
DESCRIPTOR.message_types_by_name['CancelJobsResponse'] = _CANCELJOBSRESPONSE
DESCRIPTOR.message_types_by_name['GetJobsRequest'] = _GETJOBSREQUEST
DESCRIPTOR.message_types_by_name['GetJobsResponse'] = _GETJOBSRESPONSE
DESCRIPTOR.enum_types_by_name['JobStatusEnum'] = _JOBSTATUSENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JobStatus = _reflection.GeneratedProtocolMessageType('JobStatus', (_message.Message,), dict(
  DESCRIPTOR = _JOBSTATUS,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.JobStatus)
  ))
_sym_db.RegisterMessage(JobStatus)

ScheduleJobsCypherRequest = _reflection.GeneratedProtocolMessageType('ScheduleJobsCypherRequest', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULEJOBSCYPHERREQUEST,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherRequest)
  ))
_sym_db.RegisterMessage(ScheduleJobsCypherRequest)

ScheduleJobsCypherResponse = _reflection.GeneratedProtocolMessageType('ScheduleJobsCypherResponse', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULEJOBSCYPHERRESPONSE,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherResponse)
  ))
_sym_db.RegisterMessage(ScheduleJobsCypherResponse)

CancelJobsRequest = _reflection.GeneratedProtocolMessageType('CancelJobsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CANCELJOBSREQUEST,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CancelJobsRequest)
  ))
_sym_db.RegisterMessage(CancelJobsRequest)

CancelJobsResponse = _reflection.GeneratedProtocolMessageType('CancelJobsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CANCELJOBSRESPONSE,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CancelJobsResponse)
  ))
_sym_db.RegisterMessage(CancelJobsResponse)

GetJobsRequest = _reflection.GeneratedProtocolMessageType('GetJobsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETJOBSREQUEST,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetJobsRequest)
  ))
_sym_db.RegisterMessage(GetJobsRequest)

GetJobsResponse = _reflection.GeneratedProtocolMessageType('GetJobsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETJOBSRESPONSE,
  __module__ = 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetJobsResponse)
  ))
_sym_db.RegisterMessage(GetJobsResponse)



_JOBSERVICE = _descriptor.ServiceDescriptor(
  name='JobService',
  full_name='xgt.JobService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=955,
  serialized_end=1177,
  methods=[
  _descriptor.MethodDescriptor(
    name='ScheduleJobsCypher',
    full_name='xgt.JobService.ScheduleJobsCypher',
    index=0,
    containing_service=None,
    input_type=_SCHEDULEJOBSCYPHERREQUEST,
    output_type=_SCHEDULEJOBSCYPHERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CancelJobs',
    full_name='xgt.JobService.CancelJobs',
    index=1,
    containing_service=None,
    input_type=_CANCELJOBSREQUEST,
    output_type=_CANCELJOBSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobs',
    full_name='xgt.JobService.GetJobs',
    index=2,
    containing_service=None,
    input_type=_GETJOBSREQUEST,
    output_type=_GETJOBSRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_JOBSERVICE)

DESCRIPTOR.services_by_name['JobService'] = _JOBSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*- --------------------------------------------------===#
#
#  Copyright 2018-2019 Trovares Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and 
#  limitations under the License.
#
#===----------------------------------------------------------------------===#

"""
The Python interface to the Trovares xGT graph analytics engine.

Main Features
-------------

**Data loading**

xGT is a strongly-typed graph system. Loading data is a two-step process:

1. Describe the structure and data types of your graph.

  Define the vertex and edge frame structure with `Connection.create_vertex_frame()`
  and `Connection.create_edge_frame()`. Once the type structure is set,
  `VertexFrame` and `EdgeFrame` objects provide access to the server-side
  structures.

2. Load your edge and vertex data.
    
  The `VertexFrame` and `EdgeFrame` objcts provide high-performance,
  parallel `load()` methods to ingest data as well as a direct `insert()` method
  to add small amounts of data piecewise.

**Query processing**

Queries are expressed as strings written in `TQL <http://docs.trovares.com/learn/tql_intro/index.html>`_.

>>> query = '''
      MATCH  (emp:Employee)-[edge1:ReportsTo]->(boss:Employee)
      RETURN emp.PersonID AS EmployeeID,
             boss.PersonID AS BossID
      INTO   ResultTable
      '''

A query runs in the context of a `Job`, which can be run, scheduled and
canceled. The `run_job()` method runs the query and blocks until it finishes
successfully, terminates by an error, or it's canceled.


Example
-------
The following Python script shows some of the functions that can be used to
create a graph, load data into it, run a query and access the results, and
finally remove that graph from the system. ::

  import xgt

  #-- Connect to xgtd --
  conn = xgt.Connection()

  #-- Define and create the graph --
  emp = conn.create_vertex_frame(
          name = 'Employee',
          schema = [['PersonID', xgt.INT],
                    ['Name', xgt.TEXT],
                    ['PostalCode', xgt.INT]],
          key = 'PersonID')

  rep = conn.create_edge_frame(
          name = 'ReportsTo',
          schema = [['EmpID', xgt.INT],
                    ['BossID', xgt.INT],
                    ['StartDate', xgt.DATE],
                    ['EndDate', xgt.DATE]],
          source = 'Employee',
          target = 'Employee',
          source_key = 'EmpID',
          target_key = 'BossID')

  #-- Load data to the graph in xgtd --
  # Use the insert() method for data of a few hundred rows or less;
  # for bigger amounts of data, use the load() method with csv files.
  emp.insert(
    [[111111101, 'Manny', 98103],
     [111111102, 'Trish', 98108],
     [911111501, 'Frank', 98101],
     [911111502, 'Alice', 98102]
    ])
  rep.insert(
    [[111111101, 911111501, '2015-01-03', '2017-04-14'],
     [111111102, 911111501, '2016-04-02', '2017-04-14'],
     [911111502, 911111501, '2016-07-07', '2017-04-14'],
     [111111101, 911111502, '2017-04-15', '3000-12-31'],
     [111111102, 911111502, '2017-04-15', '3000-12-31'],
     [911111501, 911111502, '2017-04-15', '3000-12-31']
    ])

  #-- Query data --
  conn.drop_frame('Result1')
  cmd = '''
    MATCH
      (emp:Employee)-[edge1:ReportsTo]->
      (boss:Employee)-[edge2:ReportsTo]->
      (emp)
    WHERE
      edge1.EndDate <= edge2.StartDate
    RETURN
      emp.PersonID AS Employee1ID,
      boss.PersonID AS Employee2ID,
      edge1.StartDate AS FirstStart,
      edge1.EndDate AS FirstEnd,
      edge2.EndDate AS SecondEnd,
      edge2.StartDate AS SecondStart
    INTO
      Result1
    '''
  conn.run_job(cmd)

  #-- Results extraction --
  ncols = len(emp.schema)
  nrows = emp.num_vertices
  print('Employee columns: {0} rows: {1} '.format(ncols, nrows))

  ncols = len(rep.schema)
  nrows = rep.num_edges
  print('ReportsTo columns: {0} rows: {1} '.format(ncols, nrows))

  r1 = conn.get_table_frame('Result1')
  ncols = (r1.schema)
  nrows = r1.num_rows
  print('Result columns: {0} rows: {1} '.format(ncols, nrows))
  print('')

  print('--- Result1 ---')
  r1dat = r1.get_data(0, 100)
  for row in r1dat:
    print(', '.join([str(c) for c in row]))
  print('')

  #-- Drop all objects --
  conn.drop_frame('ReportsTo')
  conn.drop_frame('Employee')
  conn.drop_frame('Result1')
"""

__all__ = [
  'BOOLEAN', 'INT', 'FLOAT', 'DATE', 'TIME', 'DATETIME', 'IPADDRESS', 'TEXT',
  'DEFAULT_OPT_LEVEL',
  'XgtError', 'XgtNotImplemented', 'XgtInternalError',
  'XgtIOError', 'XgtServerMemoryError', 'XgtConnectionError',
  'XgtSyntaxError', 'XgtTypeError', 'XgtValueError', 'XgtNameError',
  'XgtArithmeticError', 'XgtFrameDependencyError', 'XgtTransactionError',
  'Job', 'Connection',
  'VertexFrame', 'EdgeFrame', 'TableFrame']

################################################################################
# GRPC PRELIMINARIES
#
# gRPC has several problems with forking. Some of these are fixed in later
# versions of the library, some are still problematic. These are workarounds.

# First, gRPC in Python 2.7.5 is known to exhibit a fork bug. This seems to
# have been fixed by 2.7.10, but the intervening versions have not been tested.
# As such, we officially support only 2.7.10+.
import sys
import warnings
version_major = sys.version_info[0]
version_minor = sys.version_info[1]
version_micro = sys.version_info[2]
if ((version_major==2 and version_minor<=6) or
    (version_major==2 and version_minor==7 and version_micro<10)):
  warnings.simplefilter('module', DeprecationWarning)
  warnings.warn('xgt uses gRPC, which is known to deadlock under old versions of Python 2.7 in the presence of multiprocessing. Please either use a newer version of Python (2.7.10+) or use Python 3.', DeprecationWarning)

# Second, the "fix" for the fork bug requires that the GRPC_ENABLE_FORK_SUPPORT
# environment variable needs to be set. The grpc version must be 1.15 or later.
# See here: https://groups.google.com/forum/#!topic/grpc-io/1ABEo5e-HsU.
import os
os.environ["GRPC_ENABLE_FORK_SUPPORT"] = "1"


from .common import (
  BOOLEAN, INT, FLOAT, DATE, TIME, DATETIME, IPADDRESS, TEXT, DEFAULT_OPT_LEVEL,
  XgtError, XgtNotImplemented, XgtInternalError,
  XgtIOError, XgtServerMemoryError, XgtConnectionError,
  XgtSyntaxError, XgtTypeError, XgtValueError, XgtNameError,
  XgtArithmeticError, XgtFrameDependencyError, XgtTransactionError,
  Job
)
from .connection import Connection
from .graph import HeaderMode, VertexFrame, EdgeFrame, TableFrame

from xgt.ErrorMessages_pb2 import (
  ErrorCodeEnum
)

from xgt.JobService_pb2 import (
  JobStatusEnum
)

from .version import __version__

import warnings
warnings.filterwarnings(action='ignore', message='numpy.dtype size changed')
warnings.filterwarnings(action='ignore', message='numpy.ufunc size changed')



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AdminService.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='AdminService.proto',
  package='xgt',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x12\x41\x64minService.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\"`\n\x17\x43hangeErrorCountRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12)\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x19.xgt.ErrorCountActionEnum\"J\n\x18\x43hangeErrorCountResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x13\n\x0b\x65rror_count\x18\x02 \x01(\x05\"/\n\x11IdentifierRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\"Q\n\x12IdentifierResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12 \n\x18server_unique_identifier\x18\x02 \x01(\x04\"7\n\x19\x46reeUserMemorySizeRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\"Q\n\x1a\x46reeUserMemorySizeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x18\n\x10\x66ree_memory_size\x18\x02 \x01(\x03\"6\n\x18MaxUserMemorySizeRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\"I\n\x19MaxUserMemorySizeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x11\n\tpool_size\x18\x02 \x01(\x03\"<\n\x0fShutdownRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"-\n\x10ShutdownResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"/\n\x11StatReportRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\"I\n\x12StatReportResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x18\n\x10stat_report_json\x18\x02 \x01(\t\".\n\x10StatResetRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\".\n\x11StatResetResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\",\n\x0eVersionRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\"=\n\x0fVersionResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0f\n\x07version\x18\x02 \x01(\t*T\n\x14\x45rrorCountActionEnum\x12\x1e\n\x1aUNKNOWN_ERROR_COUNT_ACTION\x10\x00\x12\r\n\tINCREMENT\x10\x01\x12\r\n\tDECREMENT\x10\x02\x32\xc3\x04\n\x0c\x41\x64minService\x12Q\n\x10\x43hangeErrorCount\x12\x1c.xgt.ChangeErrorCountRequest\x1a\x1d.xgt.ChangeErrorCountResponse\"\x00\x12?\n\nIdentifier\x12\x16.xgt.IdentifierRequest\x1a\x17.xgt.IdentifierResponse\"\x00\x12W\n\x12\x46reeUserMemorySize\x12\x1e.xgt.FreeUserMemorySizeRequest\x1a\x1f.xgt.FreeUserMemorySizeResponse\"\x00\x12T\n\x11MaxUserMemorySize\x12\x1d.xgt.MaxUserMemorySizeRequest\x1a\x1e.xgt.MaxUserMemorySizeResponse\"\x00\x12\x39\n\x08Shutdown\x12\x14.xgt.ShutdownRequest\x1a\x15.xgt.ShutdownResponse\"\x00\x12?\n\nStatReport\x12\x16.xgt.StatReportRequest\x1a\x17.xgt.StatReportResponse\"\x00\x12<\n\tStatReset\x12\x15.xgt.StatResetRequest\x1a\x16.xgt.StatResetResponse\"\x00\x12\x36\n\x07Version\x12\x13.xgt.VersionRequest\x1a\x14.xgt.VersionResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[ErrorMessages__pb2.DESCRIPTOR,])

_ERRORCOUNTACTIONENUM = _descriptor.EnumDescriptor(
  name='ErrorCountActionEnum',
  full_name='xgt.ErrorCountActionEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR_COUNT_ACTION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCREMENT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECREMENT', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1063,
  serialized_end=1147,
)
_sym_db.RegisterEnumDescriptor(_ERRORCOUNTACTIONENUM)

ErrorCountActionEnum = enum_type_wrapper.EnumTypeWrapper(_ERRORCOUNTACTIONENUM)
UNKNOWN_ERROR_COUNT_ACTION = 0
INCREMENT = 1
DECREMENT = 2



_CHANGEERRORCOUNTREQUEST = _descriptor.Descriptor(
  name='ChangeErrorCountRequest',
  full_name='xgt.ChangeErrorCountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.ChangeErrorCountRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='xgt.ChangeErrorCountRequest.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=144,
)


_CHANGEERRORCOUNTRESPONSE = _descriptor.Descriptor(
  name='ChangeErrorCountResponse',
  full_name='xgt.ChangeErrorCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.ChangeErrorCountResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_count', full_name='xgt.ChangeErrorCountResponse.error_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=220,
)


_IDENTIFIERREQUEST = _descriptor.Descriptor(
  name='IdentifierRequest',
  full_name='xgt.IdentifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.IdentifierRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=269,
)


_IDENTIFIERRESPONSE = _descriptor.Descriptor(
  name='IdentifierResponse',
  full_name='xgt.IdentifierResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.IdentifierResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_unique_identifier', full_name='xgt.IdentifierResponse.server_unique_identifier', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=352,
)


_FREEUSERMEMORYSIZEREQUEST = _descriptor.Descriptor(
  name='FreeUserMemorySizeRequest',
  full_name='xgt.FreeUserMemorySizeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.FreeUserMemorySizeRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=409,
)


_FREEUSERMEMORYSIZERESPONSE = _descriptor.Descriptor(
  name='FreeUserMemorySizeResponse',
  full_name='xgt.FreeUserMemorySizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.FreeUserMemorySizeResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='free_memory_size', full_name='xgt.FreeUserMemorySizeResponse.free_memory_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=492,
)


_MAXUSERMEMORYSIZEREQUEST = _descriptor.Descriptor(
  name='MaxUserMemorySizeRequest',
  full_name='xgt.MaxUserMemorySizeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.MaxUserMemorySizeRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=548,
)


_MAXUSERMEMORYSIZERESPONSE = _descriptor.Descriptor(
  name='MaxUserMemorySizeResponse',
  full_name='xgt.MaxUserMemorySizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.MaxUserMemorySizeResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pool_size', full_name='xgt.MaxUserMemorySizeResponse.pool_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=623,
)


_SHUTDOWNREQUEST = _descriptor.Descriptor(
  name='ShutdownRequest',
  full_name='xgt.ShutdownRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.ShutdownRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force', full_name='xgt.ShutdownRequest.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=685,
)


_SHUTDOWNRESPONSE = _descriptor.Descriptor(
  name='ShutdownResponse',
  full_name='xgt.ShutdownResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.ShutdownResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=732,
)


_STATREPORTREQUEST = _descriptor.Descriptor(
  name='StatReportRequest',
  full_name='xgt.StatReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.StatReportRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=734,
  serialized_end=781,
)


_STATREPORTRESPONSE = _descriptor.Descriptor(
  name='StatReportResponse',
  full_name='xgt.StatReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.StatReportResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stat_report_json', full_name='xgt.StatReportResponse.stat_report_json', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=856,
)


_STATRESETREQUEST = _descriptor.Descriptor(
  name='StatResetRequest',
  full_name='xgt.StatResetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.StatResetRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=858,
  serialized_end=904,
)


_STATRESETRESPONSE = _descriptor.Descriptor(
  name='StatResetResponse',
  full_name='xgt.StatResetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.StatResetResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=906,
  serialized_end=952,
)


_VERSIONREQUEST = _descriptor.Descriptor(
  name='VersionRequest',
  full_name='xgt.VersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.VersionRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=954,
  serialized_end=998,
)


_VERSIONRESPONSE = _descriptor.Descriptor(
  name='VersionResponse',
  full_name='xgt.VersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.VersionResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='xgt.VersionResponse.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1061,
)

_CHANGEERRORCOUNTREQUEST.fields_by_name['action'].enum_type = _ERRORCOUNTACTIONENUM
_CHANGEERRORCOUNTRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_IDENTIFIERRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_FREEUSERMEMORYSIZERESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_MAXUSERMEMORYSIZERESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_SHUTDOWNRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_STATREPORTRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_STATRESETRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_VERSIONRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
DESCRIPTOR.message_types_by_name['ChangeErrorCountRequest'] = _CHANGEERRORCOUNTREQUEST
DESCRIPTOR.message_types_by_name['ChangeErrorCountResponse'] = _CHANGEERRORCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['IdentifierRequest'] = _IDENTIFIERREQUEST
DESCRIPTOR.message_types_by_name['IdentifierResponse'] = _IDENTIFIERRESPONSE
DESCRIPTOR.message_types_by_name['FreeUserMemorySizeRequest'] = _FREEUSERMEMORYSIZEREQUEST
DESCRIPTOR.message_types_by_name['FreeUserMemorySizeResponse'] = _FREEUSERMEMORYSIZERESPONSE
DESCRIPTOR.message_types_by_name['MaxUserMemorySizeRequest'] = _MAXUSERMEMORYSIZEREQUEST
DESCRIPTOR.message_types_by_name['MaxUserMemorySizeResponse'] = _MAXUSERMEMORYSIZERESPONSE
DESCRIPTOR.message_types_by_name['ShutdownRequest'] = _SHUTDOWNREQUEST
DESCRIPTOR.message_types_by_name['ShutdownResponse'] = _SHUTDOWNRESPONSE
DESCRIPTOR.message_types_by_name['StatReportRequest'] = _STATREPORTREQUEST
DESCRIPTOR.message_types_by_name['StatReportResponse'] = _STATREPORTRESPONSE
DESCRIPTOR.message_types_by_name['StatResetRequest'] = _STATRESETREQUEST
DESCRIPTOR.message_types_by_name['StatResetResponse'] = _STATRESETRESPONSE
DESCRIPTOR.message_types_by_name['VersionRequest'] = _VERSIONREQUEST
DESCRIPTOR.message_types_by_name['VersionResponse'] = _VERSIONRESPONSE
DESCRIPTOR.enum_types_by_name['ErrorCountActionEnum'] = _ERRORCOUNTACTIONENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChangeErrorCountRequest = _reflection.GeneratedProtocolMessageType('ChangeErrorCountRequest', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEERRORCOUNTREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ChangeErrorCountRequest)
  ))
_sym_db.RegisterMessage(ChangeErrorCountRequest)

ChangeErrorCountResponse = _reflection.GeneratedProtocolMessageType('ChangeErrorCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEERRORCOUNTRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ChangeErrorCountResponse)
  ))
_sym_db.RegisterMessage(ChangeErrorCountResponse)

IdentifierRequest = _reflection.GeneratedProtocolMessageType('IdentifierRequest', (_message.Message,), dict(
  DESCRIPTOR = _IDENTIFIERREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IdentifierRequest)
  ))
_sym_db.RegisterMessage(IdentifierRequest)

IdentifierResponse = _reflection.GeneratedProtocolMessageType('IdentifierResponse', (_message.Message,), dict(
  DESCRIPTOR = _IDENTIFIERRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IdentifierResponse)
  ))
_sym_db.RegisterMessage(IdentifierResponse)

FreeUserMemorySizeRequest = _reflection.GeneratedProtocolMessageType('FreeUserMemorySizeRequest', (_message.Message,), dict(
  DESCRIPTOR = _FREEUSERMEMORYSIZEREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FreeUserMemorySizeRequest)
  ))
_sym_db.RegisterMessage(FreeUserMemorySizeRequest)

FreeUserMemorySizeResponse = _reflection.GeneratedProtocolMessageType('FreeUserMemorySizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _FREEUSERMEMORYSIZERESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FreeUserMemorySizeResponse)
  ))
_sym_db.RegisterMessage(FreeUserMemorySizeResponse)

MaxUserMemorySizeRequest = _reflection.GeneratedProtocolMessageType('MaxUserMemorySizeRequest', (_message.Message,), dict(
  DESCRIPTOR = _MAXUSERMEMORYSIZEREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MaxUserMemorySizeRequest)
  ))
_sym_db.RegisterMessage(MaxUserMemorySizeRequest)

MaxUserMemorySizeResponse = _reflection.GeneratedProtocolMessageType('MaxUserMemorySizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _MAXUSERMEMORYSIZERESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MaxUserMemorySizeResponse)
  ))
_sym_db.RegisterMessage(MaxUserMemorySizeResponse)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), dict(
  DESCRIPTOR = _SHUTDOWNREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ShutdownRequest)
  ))
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), dict(
  DESCRIPTOR = _SHUTDOWNRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ShutdownResponse)
  ))
_sym_db.RegisterMessage(ShutdownResponse)

StatReportRequest = _reflection.GeneratedProtocolMessageType('StatReportRequest', (_message.Message,), dict(
  DESCRIPTOR = _STATREPORTREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StatReportRequest)
  ))
_sym_db.RegisterMessage(StatReportRequest)

StatReportResponse = _reflection.GeneratedProtocolMessageType('StatReportResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATREPORTRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StatReportResponse)
  ))
_sym_db.RegisterMessage(StatReportResponse)

StatResetRequest = _reflection.GeneratedProtocolMessageType('StatResetRequest', (_message.Message,), dict(
  DESCRIPTOR = _STATRESETREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StatResetRequest)
  ))
_sym_db.RegisterMessage(StatResetRequest)

StatResetResponse = _reflection.GeneratedProtocolMessageType('StatResetResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATRESETRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StatResetResponse)
  ))
_sym_db.RegisterMessage(StatResetResponse)

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONREQUEST,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VersionRequest)
  ))
_sym_db.RegisterMessage(VersionRequest)

VersionResponse = _reflection.GeneratedProtocolMessageType('VersionResponse', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONRESPONSE,
  __module__ = 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VersionResponse)
  ))
_sym_db.RegisterMessage(VersionResponse)



_ADMINSERVICE = _descriptor.ServiceDescriptor(
  name='AdminService',
  full_name='xgt.AdminService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1150,
  serialized_end=1729,
  methods=[
  _descriptor.MethodDescriptor(
    name='ChangeErrorCount',
    full_name='xgt.AdminService.ChangeErrorCount',
    index=0,
    containing_service=None,
    input_type=_CHANGEERRORCOUNTREQUEST,
    output_type=_CHANGEERRORCOUNTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Identifier',
    full_name='xgt.AdminService.Identifier',
    index=1,
    containing_service=None,
    input_type=_IDENTIFIERREQUEST,
    output_type=_IDENTIFIERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FreeUserMemorySize',
    full_name='xgt.AdminService.FreeUserMemorySize',
    index=2,
    containing_service=None,
    input_type=_FREEUSERMEMORYSIZEREQUEST,
    output_type=_FREEUSERMEMORYSIZERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MaxUserMemorySize',
    full_name='xgt.AdminService.MaxUserMemorySize',
    index=3,
    containing_service=None,
    input_type=_MAXUSERMEMORYSIZEREQUEST,
    output_type=_MAXUSERMEMORYSIZERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Shutdown',
    full_name='xgt.AdminService.Shutdown',
    index=4,
    containing_service=None,
    input_type=_SHUTDOWNREQUEST,
    output_type=_SHUTDOWNRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StatReport',
    full_name='xgt.AdminService.StatReport',
    index=5,
    containing_service=None,
    input_type=_STATREPORTREQUEST,
    output_type=_STATREPORTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StatReset',
    full_name='xgt.AdminService.StatReset',
    index=6,
    containing_service=None,
    input_type=_STATRESETREQUEST,
    output_type=_STATRESETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='xgt.AdminService.Version',
    index=7,
    containing_service=None,
    input_type=_VERSIONREQUEST,
    output_type=_VERSIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMINSERVICE)

DESCRIPTOR.services_by_name['AdminService'] = _ADMINSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import JobService_pb2 as JobService__pb2


class JobServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ScheduleJobsCypher = channel.unary_unary(
        '/xgt.JobService/ScheduleJobsCypher',
        request_serializer=JobService__pb2.ScheduleJobsCypherRequest.SerializeToString,
        response_deserializer=JobService__pb2.ScheduleJobsCypherResponse.FromString,
        )
    self.CancelJobs = channel.unary_unary(
        '/xgt.JobService/CancelJobs',
        request_serializer=JobService__pb2.CancelJobsRequest.SerializeToString,
        response_deserializer=JobService__pb2.CancelJobsResponse.FromString,
        )
    self.GetJobs = channel.unary_unary(
        '/xgt.JobService/GetJobs',
        request_serializer=JobService__pb2.GetJobsRequest.SerializeToString,
        response_deserializer=JobService__pb2.GetJobsResponse.FromString,
        )


class JobServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def ScheduleJobsCypher(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CancelJobs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetJobs(self, request, context):
    """Get status of one or more jobs.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ScheduleJobsCypher': grpc.unary_unary_rpc_method_handler(
          servicer.ScheduleJobsCypher,
          request_deserializer=JobService__pb2.ScheduleJobsCypherRequest.FromString,
          response_serializer=JobService__pb2.ScheduleJobsCypherResponse.SerializeToString,
      ),
      'CancelJobs': grpc.unary_unary_rpc_method_handler(
          servicer.CancelJobs,
          request_deserializer=JobService__pb2.CancelJobsRequest.FromString,
          response_serializer=JobService__pb2.CancelJobsResponse.SerializeToString,
      ),
      'GetJobs': grpc.unary_unary_rpc_method_handler(
          servicer.GetJobs,
          request_deserializer=JobService__pb2.GetJobsRequest.FromString,
          response_serializer=JobService__pb2.GetJobsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'xgt.JobService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*- --------------------------------------------------===#
#
#  Copyright 2018-2019 Trovares Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and 
#  limitations under the License.
#
#===----------------------------------------------------------------------===#

import os.path
from setuptools import setup, find_packages

basedir = os.path.dirname(__file__)
with open(os.path.join(basedir,'requirements.txt')) as f:
  requirements = f.read().splitlines()


long_description = '''
xGT is a high-performance property graph engine designed to support extremely large in-memory graphs, and the `xgt` library is the client-side interface which controls it.

## Documentation

The `xgt` library is self-documenting, and all external methods and classes have docstrings accessible through `help()`.
A formatted version of the same is available online on the Trovares documentation site: [docs.trovares.com](http://docs.trovares.com/)
'''

setup(name='xgt',
      version='1.2.0',
      author='Trovares, Inc.',
      author_email='support@trovares.com',
      description='The Python interface to the Trovares xGT graph analytics engine.',
      license='apache2',
      long_description=long_description,
      long_description_content_type='text/markdown',
      url='http://www.trovares.com/',
      packages=find_packages('src'),
      package_dir={'':'src'},
      include_package_data=True,
      install_requires=requirements,
      classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Topic :: Database',
        'Topic :: Database :: Front-Ends',
      ]
)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DataService.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='DataService.proto',
  package='xgt',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x11\x44\x61taService.proto\x12\x03xgt\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x13\x45rrorMessages.proto\"\xab\x01\n\x11UploadDataRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x17\n\x0frepository_name\x18\x02 \x01(\t\x12&\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32\x10.xgt.ContentType\x12(\n\x0bheader_mode\x18\x04 \x01(\x0e\x32\x13.xgt.HeaderModeEnum\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\"/\n\x12UploadDataResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\xe4\x01\n\x13\x44ownloadDataRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x17\n\x0frepository_name\x18\x02 \x01(\t\x12,\n\x06offset\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x06length\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x14\n\x0cwith_headers\x18\x05 \x01(\x08\x12&\n\x0c\x63ontent_type\x18\x06 \x01(\x0e\x32\x10.xgt.ContentType\"B\n\x14\x44ownloadDataResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"\x9d\x01\n\x10IngestUriRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x17\n\x0frepository_name\x18\x02 \x01(\t\x12(\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x13.xgt.HeaderModeEnum\x12\x15\n\rauthorization\x18\x04 \x01(\t\x12\x13\n\x0b\x63ontent_uri\x18\x05 \x03(\t\".\n\x11IngestUriResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"q\n\x0f\x45gestUriRequest\x12\x1a\n\x12\x65xpected_server_id\x18\x01 \x01(\x04\x12\x17\n\x0frepository_name\x18\x02 \x01(\t\x12\x13\n\x0b\x63ontent_uri\x18\x03 \x01(\t\x12\x14\n\x0cwith_headers\x18\x04 \x01(\x08\"-\n\x10\x45gestUriResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error*_\n\x0eHeaderModeEnum\x12\x17\n\x13UNKNOWN_HEADER_MODE\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x12\n\x0eIGNORE_HEADERS\x10\x02\x12\n\n\x06NORMAL\x10\x03\x12\n\n\x06STRICT\x10\x04*R\n\x0b\x43ontentType\x12\x13\n\x0fUNKNOWN_CONTENT\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\x08\n\x04JSON\x10\x02\x12\x07\n\x03ZIP\x10\x03\x12\x08\n\x04GZIP\x10\x04\x12\x08\n\x04TZIP\x10\x05\x32\x92\x02\n\x0b\x44\x61taService\x12\x41\n\nUploadData\x12\x16.xgt.UploadDataRequest\x1a\x17.xgt.UploadDataResponse\"\x00(\x01\x12G\n\x0c\x44ownloadData\x12\x18.xgt.DownloadDataRequest\x1a\x19.xgt.DownloadDataResponse\"\x00\x30\x01\x12<\n\tIngestUri\x12\x15.xgt.IngestUriRequest\x1a\x16.xgt.IngestUriResponse\"\x00\x12\x39\n\x08\x45gestUri\x12\x14.xgt.EgestUriRequest\x1a\x15.xgt.EgestUriResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,ErrorMessages__pb2.DESCRIPTOR,])

_HEADERMODEENUM = _descriptor.EnumDescriptor(
  name='HeaderModeEnum',
  full_name='xgt.HeaderModeEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_HEADER_MODE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IGNORE_HEADERS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRICT', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=971,
  serialized_end=1066,
)
_sym_db.RegisterEnumDescriptor(_HEADERMODEENUM)

HeaderModeEnum = enum_type_wrapper.EnumTypeWrapper(_HEADERMODEENUM)
_CONTENTTYPE = _descriptor.EnumDescriptor(
  name='ContentType',
  full_name='xgt.ContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_CONTENT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CSV', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZIP', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GZIP', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TZIP', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1068,
  serialized_end=1150,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
UNKNOWN_HEADER_MODE = 0
NONE = 1
IGNORE_HEADERS = 2
NORMAL = 3
STRICT = 4
UNKNOWN_CONTENT = 0
CSV = 1
JSON = 2
ZIP = 3
GZIP = 4
TZIP = 5



_UPLOADDATAREQUEST = _descriptor.Descriptor(
  name='UploadDataRequest',
  full_name='xgt.UploadDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.UploadDataRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repository_name', full_name='xgt.UploadDataRequest.repository_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='xgt.UploadDataRequest.content_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_mode', full_name='xgt.UploadDataRequest.header_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='xgt.UploadDataRequest.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=251,
)


_UPLOADDATARESPONSE = _descriptor.Descriptor(
  name='UploadDataResponse',
  full_name='xgt.UploadDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.UploadDataResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=300,
)


_DOWNLOADDATAREQUEST = _descriptor.Descriptor(
  name='DownloadDataRequest',
  full_name='xgt.DownloadDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.DownloadDataRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repository_name', full_name='xgt.DownloadDataRequest.repository_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='xgt.DownloadDataRequest.offset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='xgt.DownloadDataRequest.length', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_headers', full_name='xgt.DownloadDataRequest.with_headers', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='xgt.DownloadDataRequest.content_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=531,
)


_DOWNLOADDATARESPONSE = _descriptor.Descriptor(
  name='DownloadDataResponse',
  full_name='xgt.DownloadDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.DownloadDataResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='xgt.DownloadDataResponse.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=599,
)


_INGESTURIREQUEST = _descriptor.Descriptor(
  name='IngestUriRequest',
  full_name='xgt.IngestUriRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.IngestUriRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repository_name', full_name='xgt.IngestUriRequest.repository_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_mode', full_name='xgt.IngestUriRequest.header_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authorization', full_name='xgt.IngestUriRequest.authorization', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_uri', full_name='xgt.IngestUriRequest.content_uri', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=759,
)


_INGESTURIRESPONSE = _descriptor.Descriptor(
  name='IngestUriResponse',
  full_name='xgt.IngestUriResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.IngestUriResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=807,
)


_EGESTURIREQUEST = _descriptor.Descriptor(
  name='EgestUriRequest',
  full_name='xgt.EgestUriRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expected_server_id', full_name='xgt.EgestUriRequest.expected_server_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repository_name', full_name='xgt.EgestUriRequest.repository_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_uri', full_name='xgt.EgestUriRequest.content_uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_headers', full_name='xgt.EgestUriRequest.with_headers', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=922,
)


_EGESTURIRESPONSE = _descriptor.Descriptor(
  name='EgestUriResponse',
  full_name='xgt.EgestUriResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='xgt.EgestUriResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=969,
)

_UPLOADDATAREQUEST.fields_by_name['content_type'].enum_type = _CONTENTTYPE
_UPLOADDATAREQUEST.fields_by_name['header_mode'].enum_type = _HEADERMODEENUM
_UPLOADDATARESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_DOWNLOADDATAREQUEST.fields_by_name['offset'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_DOWNLOADDATAREQUEST.fields_by_name['length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_DOWNLOADDATAREQUEST.fields_by_name['content_type'].enum_type = _CONTENTTYPE
_DOWNLOADDATARESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_INGESTURIREQUEST.fields_by_name['header_mode'].enum_type = _HEADERMODEENUM
_INGESTURIRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
_EGESTURIRESPONSE.fields_by_name['error'].message_type = ErrorMessages__pb2._ERROR
DESCRIPTOR.message_types_by_name['UploadDataRequest'] = _UPLOADDATAREQUEST
DESCRIPTOR.message_types_by_name['UploadDataResponse'] = _UPLOADDATARESPONSE
DESCRIPTOR.message_types_by_name['DownloadDataRequest'] = _DOWNLOADDATAREQUEST
DESCRIPTOR.message_types_by_name['DownloadDataResponse'] = _DOWNLOADDATARESPONSE
DESCRIPTOR.message_types_by_name['IngestUriRequest'] = _INGESTURIREQUEST
DESCRIPTOR.message_types_by_name['IngestUriResponse'] = _INGESTURIRESPONSE
DESCRIPTOR.message_types_by_name['EgestUriRequest'] = _EGESTURIREQUEST
DESCRIPTOR.message_types_by_name['EgestUriResponse'] = _EGESTURIRESPONSE
DESCRIPTOR.enum_types_by_name['HeaderModeEnum'] = _HEADERMODEENUM
DESCRIPTOR.enum_types_by_name['ContentType'] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadDataRequest = _reflection.GeneratedProtocolMessageType('UploadDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADDATAREQUEST,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UploadDataRequest)
  ))
_sym_db.RegisterMessage(UploadDataRequest)

UploadDataResponse = _reflection.GeneratedProtocolMessageType('UploadDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADDATARESPONSE,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UploadDataResponse)
  ))
_sym_db.RegisterMessage(UploadDataResponse)

DownloadDataRequest = _reflection.GeneratedProtocolMessageType('DownloadDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _DOWNLOADDATAREQUEST,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DownloadDataRequest)
  ))
_sym_db.RegisterMessage(DownloadDataRequest)

DownloadDataResponse = _reflection.GeneratedProtocolMessageType('DownloadDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _DOWNLOADDATARESPONSE,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DownloadDataResponse)
  ))
_sym_db.RegisterMessage(DownloadDataResponse)

IngestUriRequest = _reflection.GeneratedProtocolMessageType('IngestUriRequest', (_message.Message,), dict(
  DESCRIPTOR = _INGESTURIREQUEST,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IngestUriRequest)
  ))
_sym_db.RegisterMessage(IngestUriRequest)

IngestUriResponse = _reflection.GeneratedProtocolMessageType('IngestUriResponse', (_message.Message,), dict(
  DESCRIPTOR = _INGESTURIRESPONSE,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IngestUriResponse)
  ))
_sym_db.RegisterMessage(IngestUriResponse)

EgestUriRequest = _reflection.GeneratedProtocolMessageType('EgestUriRequest', (_message.Message,), dict(
  DESCRIPTOR = _EGESTURIREQUEST,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EgestUriRequest)
  ))
_sym_db.RegisterMessage(EgestUriRequest)

EgestUriResponse = _reflection.GeneratedProtocolMessageType('EgestUriResponse', (_message.Message,), dict(
  DESCRIPTOR = _EGESTURIRESPONSE,
  __module__ = 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EgestUriResponse)
  ))
_sym_db.RegisterMessage(EgestUriResponse)



_DATASERVICE = _descriptor.ServiceDescriptor(
  name='DataService',
  full_name='xgt.DataService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1153,
  serialized_end=1427,
  methods=[
  _descriptor.MethodDescriptor(
    name='UploadData',
    full_name='xgt.DataService.UploadData',
    index=0,
    containing_service=None,
    input_type=_UPLOADDATAREQUEST,
    output_type=_UPLOADDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadData',
    full_name='xgt.DataService.DownloadData',
    index=1,
    containing_service=None,
    input_type=_DOWNLOADDATAREQUEST,
    output_type=_DOWNLOADDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='IngestUri',
    full_name='xgt.DataService.IngestUri',
    index=2,
    containing_service=None,
    input_type=_INGESTURIREQUEST,
    output_type=_INGESTURIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EgestUri',
    full_name='xgt.DataService.EgestUri',
    index=3,
    containing_service=None,
    input_type=_EGESTURIREQUEST,
    output_type=_EGESTURIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATASERVICE)

DESCRIPTOR.services_by_name['DataService'] = _DATASERVICE

# @@protoc_insertion_point(module_scope)
